<?php
/*
Plugin Name: Filedownload
Plugin URI: http://filedownload.blog-me.de/
Description: This Plugin downloads a file by opening the browsers "file save dialog", also if the filetype normally would be opened in the browser or by any other application. You can specify your own mime type. You can watch and reset the download counters in the settings menu or show the counter in your post.
Version: 2.0
Author: Peter Gross
Author URI: http://software-regensburg.de/

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
require_once(ABSPATH . 'wp-includes/ms-blogs.php');
require_once('counter.php');

######################################################
# load language files
function filedownload_add_language_files() {
  load_plugin_textdomain('filedownload', false, dirname( plugin_basename( __FILE__ ) ) );
}
add_action('init', 'filedownload_add_language_files');

register_activation_hook( __FILE__, 'filedownload_DBCreateTables' );

function filedownload_shortcode_handle($atts, $content = null) 
{
  extract(shortcode_atts(array("file" => '', "type" => '', "style" => '', "check" => '' ), $atts));

  ($style=='')?$span="<span>":$span="<span style=\"$style\">";
  $plugin_dir = WP_PLUGIN_URL;

  if ($file=="") return __("Filedownload Error: parameter 'file' is empty!",'filedownload');
  if (substr($file, 0,7) == "http://") $path = $file;
  elseif (substr($file, 0,1) == "/")   $path = WP_CONTENT_URL . $file;
  else                                 $path = WP_CONTENT_URL . '/' . $file;

  $check = strtolower(trim($check));
  if ($check != '' && $check != "no") $check = '';
  
  if ($check != "no")  {
    if (filedownload_exists($path) == false) return sprintf(__("Filedownload Error: file '%s' does not exist!",'filedownload'),$file); 
  }

  // since version 2.0: insert here a new entry in database
  filedownload_DBInsert($path); // since version 2.0: the download function only runs if the path was created here by the shortcode

  return "<a href=\"$plugin_dir/filedownload/download.php/?path=$path&type=$type&check=$check\">$span$content</span></a>";

}
add_shortcode('filedownload', 'filedownload_shortcode_handle');

function filedownload_shortcode_button_handle($atts, $content = null) 
{
  extract(shortcode_atts(array("file" => '', "type" => '', "style" => '', "check" => '' ), $atts));

  $plugin_dir = WP_PLUGIN_URL;

  if ($file=="") return __("Filedownload Error: parameter 'file' is empty!",'filedownload');
  if (substr($file, 0,7) == "http://") $path = $file;
  elseif (substr($file, 0,1) == "/")   $path = WP_CONTENT_URL . $file;
  else                                 $path = WP_CONTENT_URL . '/' . $file;

  $check = strtolower(trim($check));
  if ($check != '' && $check != "no") $check = '';
  
  if ($check != "no")  {
    if (filedownload_exists($path) == false) return sprintf(__("Filedownload Error: file '%s' does not exist!",'filedownload'),$file); 
  }

  // since version 2.0: insert here a new entry in database
  filedownload_DBInsert($path); // since version 2.0: the download function only runs if the path was created here by the shortcode
  
  return "<form action=\"$plugin_dir/filedownload/download.php/?path=$path&type=$type&check=$check\" method=\"post\"><input style=\"$style\" type=\"submit\" value=\"$content\" /></form>";

}
add_shortcode('filedownload_button', 'filedownload_shortcode_button_handle');

function filedownload_shortcode_counter_handle($atts, $content = null) 
{
  extract(shortcode_atts(array("file" => '', "style" => '' , "check" => '' ), $atts));

  ($style=='')?$span="<span>":$span="<span style=\"$style\">";

  if (substr($file, 0,7) == "http://") $filename = $file;
  elseif (substr($file, 0,1) == "/")   $filename = WP_CONTENT_URL . $file;
  else                                 $filename = WP_CONTENT_URL . '/' . $file;

  $count = strval(filedownload_DBRead($filename));

  return "$span$content$count</span></a>";

}
add_shortcode('filedownload_counter', 'filedownload_shortcode_counter_handle');


######################################################
# Start the Admin Menu dialog
if ( is_admin() ) { add_action('admin_menu', 'filedownload_menu'); }

######################################################
# End of main
######################################################

######################################################
# insert Menu 'filedownload' in settings
function filedownload_menu() {
  global $wp_version;

  if( function_exists('add_submenu_page') ) 
  {
    $menutitle = __('Filedownload','filedownload');
    $pagehook = add_submenu_page('options-general.php', $menutitle, $menutitle, 'manage_options', __FILE__, 'filedownload_options');
  }
}

######################################################
# Option Dialog function
######################################################
function filedownload_options() 
{
  if (!is_admin()) 
  {
    print "Where do you come from?!";
    return false;
  }

  $allow_url_fopen = ini_get('allow_url_fopen');
  if ($allow_url_fopen != "1") 
  {
    print '<p style="color: #FF0000; font-size: larger;">'.__('Warning: your settings in php.ini are incorrect for this plugin:','filedownload').'</p>';
    print __('<em>"allow_url_fopen" is not set to "1"</em><br />You will not be able to start downloads!<br />Please ask your provider support team to set the "php.ini" option "allow_url_fopen" to "1".','filedownload');
    echo "<br /><hr>\n";
  }
    
  # Process post
  if (isset($_POST['reset'])) 
  {
    $selected = $_POST[SELECTED];
    if (count($selected) > 0) 
    {
      print '<p style="color: #FF0000;">'.__('The following counters where set to null:','filedownload').'</p>';
      foreach ($selected as $filename)
      {
        filedownload_DBReset($filename);
        print "filename = $filename<br />";
      }
    }
    else print '<p style="color: #FF0000;">'.__('Select the counters you want to reset!','filedownload').'</p>';
  } // end of reset

  if (isset($_POST['delete'])) 
  {
    $selected = $_POST[SELECTED];
    if (count($selected) > 0) 
    {
      print '<p style="color: #FF0000;">'.__('The following counters where deleted:','filedownload').'</p>';
      foreach ($selected as $filename)
      {
        filedownload_DBDelete($filename);
        print "filename = $filename<br />";
      }
    }
    else print '<p style="color: #FF0000;">'.__('Select the counters you want to delete!','filedownload').'</p>';
  } // end of delete

  if (isset($_POST['set_options'])) 
  {
    $allow_external_download = "0";
    if (isset($_POST[ALLOW_EXTERNAL_DOWNLOAD])) $allow_external_download = "1";
    update_blog_option( get_current_blog_id(), "filedownload_allow_external_download", $allow_external_download);
    
  } // end of set_options
    
  //----------------------------------------------------------
  // Show options
  
    
  
    print '<div class="wrap"><div id="icon-options-general" class="icon32"><br /></div><h2>'.__('Settings','filedownload').' &rsaquo; '.__('filedownload','filedownload').'</h2>';    
    print '<h4>'.__('Filedownload','filedownload').'</h4>';

    // Start Form
    print '<form action="" method="post" name="form_filedownload_option">'; 
    
    printf('<table border="1" cellspacing="0" cellpadding="2" width="850px">');
    printf('<tbody>');
    printf('<tr style="background-color: #c0c0c0; text-align: center;" >');
    printf('</tr>');

    $counters = filedownload_DBReadAll();
    $i = 0;
    if (count($counters)>0)
      foreach ($counters as $counter) 
      {
        printf('<tr style="background-color: #c0c0c0; color: #E00000" >');
        print '<td width="4000px" style="padding:6px;"><input type="checkbox" name="SELECTED[' . $i++ . ']" value="'.$counter[filename].'"> '. $counter[filename] .'</td>';
        print '<td width="30px" align="left" style="padding:5px;">'.__(' Count: ','filedownload').'</td>';
        print '<td align="right" style="padding:5px;">'. $counter[count] .'</td>';
        printf('</tr>');
      }
    printf('</tbody>');
    printf('</table>');

    print "<br />";
    printf('<table border="0" cellspacing="0" cellpadding="2" width="850px">');
    printf('<tbody>');
    printf('<tr>');

    print "<td><input type='submit' name='reset' class='button-primary' value='" . __('Reset Selected Counters','filedownload') . "'></td>";  
    print "<td><input type='submit' name='delete' class='button-primary' value='" . __('Delete Selected Counters','filedownload') . "'></td>";   
    printf('</tr></tbody></table>');

    //------------- new Option from version 1.4 not allow_external_download ---------------
    echo "\n<br /><hr><br />";

    $allow_external_download = get_blog_option( get_current_blog_id(), "filedownload_allow_external_download", "0" );
    $checked = ($allow_external_download == "0") ? "" : "checked";

    print '<input type="checkbox" name="ALLOW_EXTERNAL_DOWNLOAD" value="'.$allow_external_download.'" '.$checked.'> '.__('Allow external download','filedownload');
    print ' &nbsp;&nbsp;<input type="submit" name="set_options" class="button-primary" value="'.__('Set option','filedownload').'">';
    print ' &nbsp;&nbsp;('.__('if you don´t need, unset this option to avoid spam download entries','filedownload').')';
    echo "\n<br /><br />";

    //------------- Button Set Options from version 1.4 ---------------
    printf('<table border="0" cellspacing="0" cellpadding="2" width="850px">');
    printf('<tbody>');
    printf('<tr>');
    print "<td> </td>";  
    print '<td style="text-align: right; color: #0000FF;"><i>'.__('Filedownload','filedownload').__(' is powered by ','filedownload').'<a href="http://blog-me.de" title="'.__('Create your free Wordpress Blog!', 'filedownload').'"><em>Blog-Me.de</em></a> & <a href="http://software-regensburg.de" title="'.__('Software development company.', 'filedownload').'"><em>Software-Regensburg.de</em></a></i></td>';
    printf('</tr></tbody>');
    printf('</table>');
  
    //------------- Print shortcode rules ---------------
    echo "\n<br /><hr><br />";
    print '<h4>'.__("How to insert the download link, button or download counter in your post?",'filedownload').'</h4>';

    print __('Write the following text in your post for downloading a file in a link:','filedownload').'<br /><span style="font-size:80%"><strong>[filedownload file="http://www.domain...uploads/2011/06/MTB_Tour.gpx" type="application/xml" style="color:#0000EE;"]MTB_Tour.gpx[/filedownload]</strong></span>';
    print "<br /><br />";
    print __('Write the following text in your post for downloading a file with a button:','filedownload').'<br /><span style="font-size:80%"><strong>[filedownload_button file="http://www.domain...uploads/2011/06/MTB_Tour.gpx"]Download[/filedownload_button]</strong></span>';
    print "<br /><br />";
    print __('Write the following text in your post for showing the download counter:','filedownload').'<br /><span style="font-size:80%"><strong>[filedownload_counter file="http://www.domain...uploads/2011/06/MTB_Tour.gpx" style="color:#FF0000;"]Downloads:[/filedownload_counter]</strong></span>';
    print "<br /><br />";
    print __('where <strong>type</strong> and <strong>style</strong> are optional','filedownload');
    print "<br /><br />";
    print __('use <strong>check="no"</strong> to refer at a file link where php cannot access','filedownload');
    print "<br /><br /><hr><br />";

    print "</form>";  
    print '</div>';


}

?>